# fasjson-client

A python client library for the FASJSON API

This client uses the bravado library to build dynamic api methods based on open-api specs (version 2.0): https://github.com/Yelp/bravado

The documentation is available at https://fasjson-client.readthedocs.io/

## License

Licensed under [lgpl-3.0](./LICENSE)
